"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const global_1 = __importDefault(require("./global"));
const os_1 = require("os");
exports.testEnv = () => {
    const OLD_ENV = process.env;
    beforeEach(() => {
        jest.resetModules();
        process.env = Object.assign({}, OLD_ENV);
        delete process.env.NODE_ENV;
    });
    afterEach(() => {
        process.env = OLD_ENV;
    });
};
exports.testChildProcess = () => {
    afterEach(() => {
        global_1.default.mockChildProcess.stdout = 'stdout';
        global_1.default.mockChildProcess.stderr = '';
        global_1.default.mockChildProcess.error = null;
    });
};
exports.spyOnStdout = () => jest.spyOn(global_1.default.mockStdout, 'write');
exports.stdoutCalledWith = (spyOnMock, messages) => {
    expect(spyOnMock).toBeCalledTimes(messages.length);
    messages.forEach((message, index) => {
        expect(spyOnMock.mock.calls[index][0]).toBe(message + os_1.EOL);
    });
};
exports.spyOnExec = () => jest.spyOn(global_1.default.mockChildProcess, 'exec');
exports.execCalledWith = (spyOnMock, messages) => {
    expect(spyOnMock).toBeCalledTimes(messages.length);
    messages.forEach((message, index) => {
        expect(spyOnMock.mock.calls[index][0]).toBe(message);
    });
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.testProperties = (object, checks) => {
    expect(typeof object).toBe('object');
    Object.keys(checks).forEach(key => {
        expect(object).toHaveProperty(key);
        if (typeof checks[key] === 'object') {
            expect(object[key]).toEqual(checks[key]);
        }
        else {
            expect(object[key]).toBe(checks[key]);
        }
    });
};
//# sourceMappingURL=utils.js.map